@@ -1,4 +1,4 @@
-/** @file version.h
+/** @file
  * @brief Define preprocessor symbols for the library version
  */
 // Copyright (C) 2002,2004,2005,2006,2007,2008,2009,2010,2011,2012,2013,2015,2016,2017,2018,2020 Olly Betts
@@ -29,12 +29,12 @@
 #warning The C++ ABI version of compiler you are using does not exactly match
 #warning that of the compiler used to build the library. If linking fails
 #warning due to missing symbols, this is probably the reason why.
-#warning The Xapian library was built with clang++ 10.0.1 
+#warning The Xapian library was built with clang++ 11.1.0 
 #else
 #error The C++ ABI version of compiler you are using does not match
 #error that of the compiler used to build the library. The versions
 #error must match or your program will not work correctly.
-#error The Xapian library was built with clang++ 10.0.1 
+#error The Xapian library was built with clang++ 11.1.0 
 #endif
 #endif
 
@@ -50,7 +50,7 @@
 #define XAPIAN_ENABLE_VISIBILITY
 
 /// The version of Xapian as a C string literal.
-#define XAPIAN_VERSION "1.4.16"
+#define XAPIAN_VERSION "1.4.18"
 
 /** The major component of the Xapian version.
  * E.g. for Xapian 1.0.14 this would be: 1
@@ -65,7 +65,7 @@
 /** The revision component of the Xapian version.
  * E.g. for Xapian 1.0.14 this would be: 14
  */
-#define XAPIAN_REVISION 16
+#define XAPIAN_REVISION 18
 
 /// Base (signed) type for Xapian::docid and related types.
 #define XAPIAN_DOCID_BASE_TYPE int
@@ -77,10 +77,10 @@
 #define XAPIAN_TERMPOS_BASE_TYPE int
 
 /// Type for returning total document length.
-#define XAPIAN_TOTALLENGTH_TYPE unsigned long
+#define XAPIAN_TOTALLENGTH_TYPE unsigned long long
 
 /// Underlying type for Xapian::rev.
-#define XAPIAN_REVISION_TYPE unsigned long
+#define XAPIAN_REVISION_TYPE unsigned long long
 
 /// XAPIAN_HAS_CHERT_BACKEND Defined if the chert backend is enabled.
 #define XAPIAN_HAS_CHERT_BACKEND 1
